@@ -277,19 +277,20 @@ public:
   Graph *addSubGraph(std::string name);
 
   /**
-   * @brief Creates and returns a subgraph of this graph that contains all its elements.
+   * @brief Creates and returns a subgraph that contains all the elements of this graph.
    *
    * @param name The name of the newly created subgraph. Defaults to "unnamed".
-   * @return :Graph* The newly created clone subgraph.
+   * @param addSibling if true the clone subgraph will be a sibling of this graph, if false (the default) it will be a subgraph of this graph
+   * @return :Graph* The newly created clone subgraph. NULL will be returned if addSibling is set to true and this graph is a root graph.
    **/
-  virtual Graph* addCloneSubGraph(std::string name = "unnamed");
+  virtual Graph* addCloneSubGraph(std::string name = "unnamed", bool addSibling = false);
 
   /**
    * @brief Creates and returns a new sub-graph of the graph induced by a set of nodes.
    * Every node contained in the given set of nodes is added to the subgraph.
    * Every edge connecting any two nodes in the set of given nodes is also added.
    * @param nodeSet The nodes to add to the subgraph. All the edges between these nodes are added too.
-   * @param parentSubGraph If provided, is used as parent graph for the newly created subgraph instead of the Graph this method is called on.
+   * @param parentSubGraph If provided, is used as parent graph for the newly created subgraph instead of the graph this method is called on.
    * @return The newly created subgraph.
    */
   Graph *inducedSubGraph(const std::set<node>& nodeSet,
@@ -521,6 +522,17 @@ public:
    */
   virtual void addNodes(Iterator<node>* nodes)=0;
 
+  /**
+  * @brief Adds existing nodes in the graph. The nodes are also added in all the ancestor graphs.
+  * as with addNode(const tlp::node), the nodes must exist in the graph hierarchy and thus exist in the root graph,
+  * and nodes cannot be added this way to the root graph.
+
+  * @warning Using this method on the root graph will display a warning on the console.
+  *
+  * @param nodes a vector of nodes to add to this subgraph.
+  */
+  void addNodes(const std::vector<node>& nodes);
+
   /**
    * @brief Deletes a node in the graph.
    * This node is also removed in the sub-graphs hierarchy of the current graph.
@@ -532,7 +544,7 @@ public:
 
   /**
    * @brief Deletes nodes in the graph.
-   * Thess nodes are also removed in the sub-graphs hierarchy of the current graph.
+   * These nodes are also removed in the sub-graphs hierarchy of the current graph.
    * @warning the graph does not take ownership of the Iterator.
    * @param it The nodes to delete.
    * @param deleteInAllGraphs Whether to delete in all its parent graphs or only in this graph. By default only removes in the current graph.
@@ -540,6 +552,16 @@ public:
    */
   virtual void delNodes(Iterator<node>* it, bool deleteInAllGraphs = false)=0;
 
+  /**
+   * @brief Deletes nodes in the graph.
+   * These nodes are also removed in the sub-graphs hierarchy of the current graph.
+   * @warning the graph does not take ownership of the Iterator.
+   * @param nodes a vector of the nodes to delete.
+   * @param deleteInAllGraphs Whether to delete in all its parent graphs or only in this graph. By default only removes in the current graph.
+   * @see delNode() to remove a single node.
+   */
+  void delNodes(const std::vector<node>& nodes, bool deleteInAllGraphs = false);
+
   /**
    * @brief Adds a new edge in the graph
    * This edge is also added in all the super-graph of the graph.
@@ -587,6 +609,16 @@ public:
    */
   virtual void addEdges(Iterator<edge>* edges)=0;
 
+  /**
+   * @brief Adds existing edges in the graph. The edges are also added in all
+   * the ancestor graphs.
+   * The added edges must be elements of the graph hierarchy,
+   * thus they must be elements of the root graph.
+   * @warning Using this method on the root graph will display a warning on the console.
+   * @param edges a vector of the edges to add on this subgraph.
+   */
+  void addEdges(const std::vector<edge>& edges);
+
   /**
    * @brief Deletes an edge in the graph. The edge is also removed in
    * the sub-graphs hierarchy.
@@ -605,6 +637,15 @@ public:
    */
   virtual void delEdges(Iterator<edge>* itE, bool deleteInAllGraphs = false)=0;
 
+  /**
+   * @brief Deletes edges in the graph. These edges are also removed in the sub-graphs hierarchy.
+   * The ordering of remaining edges is preserved.
+   * @warning The graph does not take ownership of the Iterator.
+   * @param edges a vector of the edges to delete
+   * @param deleteInAllGraphs  Whether to delete in all its parent graphs or only in this graph. By default only removes in the current graph.
+   */
+  void delEdges(const std::vector<edge>& edges, bool deleteInAllGraphs = false);
+
   /**
    * @brief Sets the order of the edges around a node.
    * This operation ensures that adjacent edges of a node will
