@@ -25,7 +25,7 @@
 #define OS_PLATFORM "win"
 #elif defined(__APPLE__)
 #define OS_PLATFORM "mac"
-#elif defined(__linux)
+#elif defined(__linux__)
 #define OS_PLATFORM "linux"
 #else
 #define OS_PLATFORM "other"
@@ -35,6 +35,8 @@
 #define OS_ARCHITECTURE "x86_64"
 #elif defined(__i386__) || defined(_M_IX86)
 #define OS_ARCHITECTURE "x86"
+#else
+#define OS_ARCHITECTURE "other"
 #endif
 
 #if defined(__clang__)
