@@ -21,6 +21,7 @@
 #include <fstream>
 
 #include <tulip/ForEach.h>
+#include <tulip/StlIterator.h>
 #include <tulip/TlpTools.h>
 #include <tulip/Graph.h>
 #include <tulip/GraphImpl.h>
@@ -225,8 +226,8 @@ Graph * tlp::loadGraph(const std::string &filename, PluginProgress *progress) {
     algName = "JSON Import";*/
 
   dataSet.set("file::filename", filename);
-  Graph *sg = tlp::importGraph(algName, dataSet,progress);
-  return sg;
+  Graph *graph = tlp::importGraph(algName, dataSet,progress);
+  return graph;
 }
 //=========================================================
 bool tlp::saveGraph(Graph* graph, const std::string& filename, PluginProgress *progress) {
@@ -245,7 +246,7 @@ bool tlp::saveGraph(Graph* graph, const std::string& filename, PluginProgress *p
   return result;
 }
 //=========================================================
-Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProgress *progress, Graph *newGraph) {
+Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProgress *progress, Graph *graph) {
 
   if (!PluginLister::pluginExists(format)) {
     tlp::warning() << "libtulip: " << __FUNCTION__ << ": import plugin \"" << format
@@ -255,8 +256,8 @@ Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProg
 
   bool newGraphP=false;
 
-  if (newGraph==NULL) {
-    newGraph=new GraphImpl();
+  if (graph==NULL) {
+    graph=tlp::newGraph();
     newGraphP=true;
   }
 
@@ -269,21 +270,22 @@ Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProg
   }
   else tmpProgress=progress;
 
-  AlgorithmContext* tmp = new AlgorithmContext(newGraph, &dataSet, tmpProgress);
+  AlgorithmContext* tmp = new AlgorithmContext(graph, &dataSet, tmpProgress);
   ImportModule *newImportModule = PluginLister::instance()->getPluginObject<ImportModule>(format, tmp);
   assert(newImportModule!=NULL);
 
-  bool importSucessfull = newImportModule->importGraph();
-
   //If the import failed and we created the graph then delete the graph
-  if (!importSucessfull && newGraphP) {
-    delete newGraph;
+  if (!newImportModule->importGraph()) {
+    graph = NULL;
+
+    if (newGraphP)
+      delete graph;
   }
   else {
     std::string filename;
 
     if (dataSet.get("file::filename", filename)) {
-      newGraph->setAttribute("file", filename);
+      graph->setAttribute("file", filename);
     }
   }
 
@@ -292,15 +294,10 @@ Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProg
   delete newImportModule;
   dataSet = *tmp->dataSet;
 
-  if (importSucessfull) {
-    setViewPropertiesDefaults(newGraph);
-    return newGraph;
-  }
-  else
-    return NULL;
+  return graph;
 }
 //=========================================================
-bool tlp::exportGraph(Graph *sg, std::ostream &outputStream, const std::string &format,
+bool tlp::exportGraph(Graph *graph, std::ostream &outputStream, const std::string &format,
                       DataSet &dataSet, PluginProgress *progress) {
   if (!PluginLister::pluginExists(format)) {
     tlp::warning() << "libtulip: " << __FUNCTION__ << ": export plugin \"" << format
@@ -318,13 +315,13 @@ bool tlp::exportGraph(Graph *sg, std::ostream &outputStream, const std::string &
   }
   else tmpProgress=progress;
 
-  AlgorithmContext* context = new AlgorithmContext(sg, &dataSet, tmpProgress);
+  AlgorithmContext* context = new AlgorithmContext(graph, &dataSet, tmpProgress);
   ExportModule *newExportModule=PluginLister::instance()->getPluginObject<ExportModule>(format, context);
   assert(newExportModule!=NULL);
   std::string filename;
 
   if (dataSet.get("file", filename)) {
-    sg->setAttribute("file", filename);
+    graph->setAttribute("file", filename);
   }
 
   result=newExportModule->exportGraph(outputStream);
@@ -694,77 +691,77 @@ void Graph::notifyAfterSetEnds(const edge e) {
     sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_SET_ENDS, e));
 }
 
-void Graph::notifyBeforeAddSubGraph(const Graph* sg) {
+void Graph::notifyBeforeAddSubGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_ADD_SUBGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_ADD_SUBGRAPH, graph));
 
   Graph *g = this;
 
   while (g != getRoot()) {
-    g->notifyBeforeAddDescendantGraph(sg);
+    g->notifyBeforeAddDescendantGraph(graph);
     g = g->getSuperGraph();
   }
 
-  getRoot()->notifyBeforeAddDescendantGraph(sg);
+  getRoot()->notifyBeforeAddDescendantGraph(graph);
 }
 
-void Graph::notifyAfterAddSubGraph(const Graph* sg) {
+void Graph::notifyAfterAddSubGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_ADD_SUBGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_ADD_SUBGRAPH, graph));
 
   Graph *g = this;
 
   while (g != getRoot()) {
-    g->notifyAfterAddDescendantGraph(sg);
+    g->notifyAfterAddDescendantGraph(graph);
     g = g->getSuperGraph();
   }
 
-  getRoot()->notifyAfterAddDescendantGraph(sg);
+  getRoot()->notifyAfterAddDescendantGraph(graph);
 }
 
-void Graph::notifyBeforeDelSubGraph(const Graph* sg) {
+void Graph::notifyBeforeDelSubGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_SUBGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_SUBGRAPH, graph));
 
   Graph *g = this;
 
   while (g != getRoot()) {
-    g->notifyBeforeDelDescendantGraph(sg);
+    g->notifyBeforeDelDescendantGraph(graph);
     g = g->getSuperGraph();
   }
 
-  getRoot()->notifyBeforeDelDescendantGraph(sg);
+  getRoot()->notifyBeforeDelDescendantGraph(graph);
 }
-void Graph::notifyAfterDelSubGraph(const Graph* sg) {
+void Graph::notifyAfterDelSubGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_DEL_SUBGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_DEL_SUBGRAPH, graph));
 
   Graph *g = this;
 
   while (g != getRoot()) {
-    g->notifyAfterDelDescendantGraph(sg);
+    g->notifyAfterDelDescendantGraph(graph);
     g = g->getSuperGraph();
   }
 
-  getRoot()->notifyAfterDelDescendantGraph(sg);
+  getRoot()->notifyAfterDelDescendantGraph(graph);
 }
 
-void Graph::notifyBeforeAddDescendantGraph(const Graph* sg) {
+void Graph::notifyBeforeAddDescendantGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_ADD_DESCENDANTGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_ADD_DESCENDANTGRAPH, graph));
 }
-void Graph::notifyAfterAddDescendantGraph(const Graph* sg) {
+void Graph::notifyAfterAddDescendantGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_ADD_DESCENDANTGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_ADD_DESCENDANTGRAPH, graph));
 }
 
-void Graph::notifyBeforeDelDescendantGraph(const Graph* sg) {
+void Graph::notifyBeforeDelDescendantGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_DESCENDANTGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_DESCENDANTGRAPH, graph));
 }
-void Graph::notifyAfterDelDescendantGraph(const Graph* sg) {
+void Graph::notifyAfterDelDescendantGraph(const Graph* graph) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_DEL_DESCENDANTGRAPH, sg));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_DEL_DESCENDANTGRAPH, graph));
 }
 
 void Graph::notifyBeforeAddLocalProperty(const std::string& propName) {
@@ -1033,11 +1030,21 @@ Graph* Graph::addSubGraph(std::string name) {
   return g;
 }
 //=========================================================
-Graph* Graph::addCloneSubGraph(std::string name) {
+Graph* Graph::addCloneSubGraph(std::string name, bool addSibling) {
   BooleanProperty selection(this);
   selection.setAllNodeValue(true);
   selection.setAllEdgeValue(true);
-  return addSubGraph(&selection, name);
+  Graph* parentSubGraph = this;
+
+  if (addSibling) {
+    parentSubGraph = getSuperGraph();
+
+    if (this == parentSubGraph)
+      // cannot add sibling of root graph
+      return NULL;
+  }
+
+  return parentSubGraph->addSubGraph(&selection, name);
 }
 //=========================================================
 Graph * Graph::inducedSubGraph(const std::set<node> &nodes,
@@ -1633,3 +1640,22 @@ const std::string& GraphEvent::getPropertyName() const {
   return *(info.name);
 }
 
+void Graph::addNodes(const std::vector<node>& nodes) {
+  StlIterator<node, vector<node>::const_iterator> vIterator(nodes.begin(), nodes.end());
+  addNodes(&vIterator);
+}
+
+void Graph::delNodes(const std::vector<node>& nodes, bool deleteInAllGraphs) {
+  StlIterator<node, vector<node>::const_iterator> vIterator(nodes.begin(), nodes.end());
+  delNodes(&vIterator, deleteInAllGraphs);
+}
+
+void Graph::addEdges(const std::vector<edge>& edges) {
+  StlIterator<edge, vector<edge>::const_iterator> vIterator(edges.begin(), edges.end());
+  addEdges(&vIterator);
+}
+
+void Graph::delEdges(const std::vector<edge>& edges, bool deleteInAllGraphs) {
+  StlIterator<edge, vector<edge>::const_iterator> vIterator(edges.begin(), edges.end());
+  delEdges(&vIterator, deleteInAllGraphs);
+}
