@@ -33,20 +33,18 @@ class ColorScaleConfigDialog;
 class TLP_QT_SCOPE ColorScaleButton: public QPushButton {
   Q_OBJECT
   ColorScale _colorScale;
-  ColorScaleConfigDialog* _dlg;
 public:
   static void paintScale(QPainter*,const QRect&, const ColorScale&);
 
   ColorScaleButton(ColorScale colorScale=ColorScale(), QWidget* parent=NULL);
-  virtual ~ColorScaleButton();
 
-  ColorScale colorScale() const;
-  void setColorScale(const ColorScale& colorScale);
+  const ColorScale& colorScale() const;
+  void setColorScale(const ColorScale&) const;
   void paintEvent(QPaintEvent *event);
+  void editColorScale(const ColorScale& colorScale);
 
-
-protected slots:
-  void showDialog();
+public slots:
+  void editColorScale();
 };
 
 }
