@@ -128,7 +128,7 @@ void GlMainWidget::doSelect(const int x, const int y,
 
 //==================================================
 GlMainWidget::GlMainWidget(QWidget *parent,View *view):
-  QGLWidget(GlInit(), parent, getFirstQGLWidget()),scene(new GlQuadTreeLODCalculator),view(view),widthStored(0),heightStored(0), useFramebufferObject(false), glFrameBuf(NULL) {
+  QGLWidget(GlInit(), parent, getFirstQGLWidget()),scene(new GlQuadTreeLODCalculator),view(view),widthStored(0),heightStored(0), useFramebufferObject(false), glFrameBuf(NULL), keepPointOfViewOnSubgraphChanging(false) {
   assert(this->isValid());
   setFocusPolicy(Qt::StrongFocus);
   setMouseTracking(true);
@@ -546,10 +546,12 @@ QImage GlMainWidget::createPicture(int width, int height,bool center) {
   return QImage(resultImage.bits(),resultImage.width(),resultImage.height(),QImage::Format_ARGB32).convertToFormat(QImage::Format_RGB32);
 }
 
-  void GlMainWidget::centerScene(bool graphChanged, float zf) {
+void GlMainWidget::centerScene(bool graphChanged, float zf) {
   scene.centerScene();
+
   if (zf != 1)
     scene.zoomFactor(zf);
+
   draw(graphChanged);
 }
 
@@ -557,4 +559,13 @@ void GlMainWidget::emitGraphChanged() {
   emit graphChanged();
 }
 
+
+void GlMainWidget::setKeepScenePointOfViewOnSubgraphChanging(bool k) {
+  keepPointOfViewOnSubgraphChanging = k;
+}
+
+bool GlMainWidget::keepScenePointOfViewOnSubgraphChanging() const {
+  return keepPointOfViewOnSubgraphChanging;
+}
+
 }
