@@ -100,7 +100,9 @@ public:
     }
 
     delete itN;
-    label->setNodeValue(mN, label->getNodeValue(viewMetricMaxNode));
+
+    if (viewMetricMaxNode.isValid())
+      label->setNodeValue(mN, label->getNodeValue(viewMetricMaxNode));
   }
 };
 
@@ -624,8 +626,10 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
         Graph* parentGraph = sg->getSuperGraph();
         QModelIndex index = indexOf(sg);
         assert(index.isValid());
+#ifndef NDEBUG
         QModelIndex parentIndex = indexOf(parentGraph);
         assert(parentIndex.isValid());
+#endif
 
         emit layoutAboutToBeChanged();
 
