@@ -250,8 +250,7 @@ void GraphModel::treatEvent(const Event& ev) {
   MACRO(GraphProperty,tlp::Graph*);\
   MACRO(IntegerProperty,int);\
   MACRO(IntegerVectorProperty,std::vector<int>);\
-  MACRO(BooleanProperty,bool);\
-  MACRO(BooleanVectorProperty,std::vector<bool>);
+  MACRO(BooleanProperty,bool);
 
 #define STANDARD_EDGE_CHECKS(MACRO) \
   MACRO(DoubleProperty,double);\
@@ -267,8 +266,7 @@ void GraphModel::treatEvent(const Event& ev) {
   MACRO(CoordVectorProperty,std::vector<tlp::Coord>);\
   MACRO(IntegerProperty,int);\
   MACRO(IntegerVectorProperty,std::vector<int>);\
-  MACRO(BooleanProperty,bool);\
-  MACRO(BooleanVectorProperty,std::vector<bool>);
+  MACRO(BooleanProperty,bool);
 
 
 #define GET_NODE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) return QVariant::fromValue< TYPE >(static_cast<PROP*>(prop)->getNodeValue(n))
@@ -277,40 +275,62 @@ QVariant GraphModel::nodeValue(unsigned int id, PropertyInterface * prop) {
 
   if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
     return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str())));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str()),TulipFileDescriptor::File));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str())));
+
+    if (prop->getName() == "viewTexture")
+      return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str()),TulipFileDescriptor::File));
+
+    return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getNodeValue(n)));
 
   STANDARD_NODE_CHECKS(GET_NODE_VALUE)
   return QVariant();
 }
+
 #define GET_NODE_DEFAULT_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) return QVariant::fromValue< TYPE >(static_cast<PROP*>(prop)->getNodeDefaultValue())
 QVariant GraphModel::nodeDefaultValue(PropertyInterface * prop) {
   if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
     return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str())));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str()),TulipFileDescriptor::File));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str())));
+
+    if (prop->getName() == "viewTexture")
+      return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str()),TulipFileDescriptor::File));
+
+    return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getNodeDefaultValue()));
 
   STANDARD_NODE_CHECKS(GET_NODE_DEFAULT_VALUE)
   return QVariant();
 }
+
 #define SET_ALL_NODE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) static_cast<PROP*>(prop)->setAllNodeValue(v.value< TYPE >())
 bool GraphModel::setAllNodeValue(PropertyInterface * prop, QVariant v) {
   if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
     static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<NodeShape::NodeShapes>());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    static_cast<StringProperty*>(prop)->setAllNodeValue(v.value<TulipFont>().fontFile().toStdString());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewTexture")
+      static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+    else
+      static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<QString>().toUtf8().data()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<LabelPosition::LabelPositions>());
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    static_cast<BooleanVectorProperty*>(prop)->setAllNodeValue(v.value<QVector<bool> >().toStdVector());
 
   STANDARD_NODE_CHECKS(SET_ALL_NODE_VALUE)
   else
@@ -318,18 +338,25 @@ bool GraphModel::setAllNodeValue(PropertyInterface * prop, QVariant v) {
 
   return true;
 }
+
 #define SET_NODE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) static_cast<PROP*>(prop)->setNodeValue(n,v.value< TYPE >())
 bool GraphModel::setNodeValue(unsigned int id, PropertyInterface * prop, QVariant v) {
   node n(id);
 
   if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
     static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<NodeShape::NodeShapes>());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    static_cast<StringProperty*>(prop)->setNodeValue(n,v.value<TulipFont>().fontFile().toStdString());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      static_cast<StringProperty*>(prop)->setNodeValue(n, std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewTexture")
+      static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+    else
+      static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<QString>().toUtf8().data()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<LabelPosition::LabelPositions>());
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    static_cast<BooleanVectorProperty*>(prop)->setNodeValue(n,v.value<QVector<bool> >().toStdVector());
 
   STANDARD_NODE_CHECKS(SET_NODE_VALUE)
   else
@@ -348,16 +375,24 @@ QVariant GraphModel::edgeValue(unsigned int id, PropertyInterface * prop) {
     return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
     return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    return QVariant::fromValue<TulipFont>(TulipFont::fromFile(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()),TulipFileDescriptor::File));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str())));
+
+    if (prop->getName() == "viewTexture")
+      return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()),TulipFileDescriptor::File));
+
+    return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getEdgeValue(e)));
 
   STANDARD_EDGE_CHECKS(GET_EDGE_VALUE)
   return QVariant();
 }
+
 #define GET_EDGE_DEFAULT_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) return QVariant::fromValue< TYPE >(static_cast<PROP*>(prop)->getEdgeDefaultValue())
 QVariant GraphModel::edgeDefaultValue(PropertyInterface * prop) {
   if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
@@ -366,16 +401,24 @@ QVariant GraphModel::edgeDefaultValue(PropertyInterface * prop) {
     return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
     return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    return QVariant::fromValue<TulipFont>(TulipFont::fromFile(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()));
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()),TulipFileDescriptor::File));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      return QVariant::fromValue<TulipFont>(TulipFont::fromFile(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()));
+
+    if (prop->getName() == "viewTexture")
+      return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()),TulipFileDescriptor::File));
+
+    return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getEdgeDefaultValue()));
 
   STANDARD_EDGE_CHECKS(GET_EDGE_DEFAULT_VALUE)
   return QVariant();
 }
+
 #define SET_EDGE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) static_cast<PROP*>(prop)->setEdgeValue(e,v.value< TYPE >())
 bool GraphModel::setEdgeValue(unsigned int id, PropertyInterface* prop, QVariant v) {
   edge e(id);
@@ -386,12 +429,18 @@ bool GraphModel::setEdgeValue(unsigned int id, PropertyInterface* prop, QVariant
     static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
     static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    static_cast<StringProperty*>(prop)->setEdgeValue(e,v.value<TulipFont>().fontFile().toStdString());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    static_cast<StringProperty*>(prop)->setEdgeValue(e,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      static_cast<StringProperty*>(prop)->setEdgeValue(e, std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewTexture")
+      static_cast<StringProperty*>(prop)->setEdgeValue(e,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+    else
+      static_cast<StringProperty*>(prop)->setEdgeValue(e, std::string(v.value<QString>().toUtf8().data()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<LabelPosition::LabelPositions>());
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    static_cast<BooleanVectorProperty*>(prop)->setEdgeValue(e, v.value<QVector<bool> >().toStdVector());
 
   STANDARD_EDGE_CHECKS(SET_EDGE_VALUE)
   else
@@ -407,12 +456,18 @@ bool GraphModel::setAllEdgeValue(PropertyInterface* prop, QVariant v) {
     static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
     static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewFont")
-    static_cast<StringProperty*>(prop)->setAllEdgeValue(v.value<TulipFont>().fontFile().toStdString());
-  else if (dynamic_cast<StringProperty*>(prop) != NULL && prop->getName() == "viewTexture")
-    static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+  else if (dynamic_cast<StringProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewFont")
+      static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewTexture")
+      static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+    else
+      static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<QString>().toUtf8().data()));
+  }
   else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
     static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<LabelPosition::LabelPositions>());
+  else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
+    static_cast<BooleanVectorProperty*>(prop)->setAllEdgeValue(v.value<QVector<bool> >().toStdVector());
 
   STANDARD_EDGE_CHECKS(SET_ALL_EDGE_VALUE)
   else
@@ -444,7 +499,7 @@ void NodesGraphModel::setGraph(Graph* g) {
 }
 
 QString NodesGraphModel::stringValue(unsigned int id, PropertyInterface* pi) const {
-  return pi->getNodeStringValue(node(id)).c_str();
+  return QString::fromUtf8(pi->getNodeStringValue(node(id)).c_str());
 }
 
 QVariant NodesGraphModel::value(unsigned int id, PropertyInterface* prop) const {
@@ -465,7 +520,7 @@ bool NodesGraphModel::setValue(unsigned int id, PropertyInterface* prop, QVarian
 EdgesGraphModel::EdgesGraphModel(QObject *parent): GraphModel(parent) {
 }
 QString EdgesGraphModel::stringValue(unsigned int id, PropertyInterface* pi) const {
-  return pi->getEdgeStringValue(edge(id)).c_str();
+  return QString::fromUtf8(pi->getEdgeStringValue(edge(id)).c_str());
 }
 
 void EdgesGraphModel::setGraph(Graph* g) {
