@@ -204,6 +204,10 @@ void NodeLinkDiagramComponent::setState(const tlp::DataSet& data) {
     data.get<bool>("quickAccessBarVisible",quickAccessBarVisible);
   }
 
+  bool keepSPOV = false;
+  data.get<bool>("keepScenePointOfViewOnSubgraphChanging", keepSPOV);
+  getGlMainWidget()->setKeepScenePointOfViewOnSubgraphChanging(keepSPOV);
+
   createScene(graph(), data);
   registerTriggers();
   setOverviewVisible(overviewVisible);
@@ -215,9 +219,17 @@ void NodeLinkDiagramComponent::setState(const tlp::DataSet& data) {
 }
 
 void NodeLinkDiagramComponent::graphChanged(tlp::Graph* graph) {
+  GlGraphComposite* composite =
+    getGlMainWidget()->getScene()->getGlGraphComposite();
+  Graph* oldGraph = composite ? composite->getGraph() : NULL;
   loadGraphOnScene(graph);
   registerTriggers();
-  centerView();
+
+  if (oldGraph == NULL || graph == NULL ||
+      (oldGraph->getRoot() != graph->getRoot()) ||
+      getGlMainWidget()->keepScenePointOfViewOnSubgraphChanging() == false)
+    centerView();
+
   emit drawNeeded();
   drawOverview();
 }
@@ -226,6 +238,8 @@ tlp::DataSet NodeLinkDiagramComponent::state() const {
   DataSet data=sceneData();
   data.set("overviewVisible",overviewVisible());
   data.set("quickAccessBarVisible",quickAccessBarVisible());
+  data.set("keepScenePointOfViewOnSubgraphChanging",
+           getGlMainWidget()->keepScenePointOfViewOnSubgraphChanging());
   return data;
 }
 
@@ -346,6 +360,7 @@ void NodeLinkDiagramComponent::loadGraphOnScene(Graph *graph) {
 
   GlGraphRenderingParameters param=oldGraphComposite->getRenderingParameters();
   GlMetaNodeRenderer *metaNodeRenderer=oldGraphComposite->getInputData()->getMetaNodeRenderer();
+  // prevent deletion of MetaNodeRenderer when deleting oldGraphComposite
   oldGraphComposite->getInputData()->setMetaNodeRenderer(NULL,false);
   GlGraphComposite* graphComposite=new GlGraphComposite(graph);
   graphComposite->setRenderingParameters(param);
@@ -355,11 +370,9 @@ void NodeLinkDiagramComponent::loadGraphOnScene(Graph *graph) {
   graphComposite->getInputData()->setMetaNodeRenderer(metaNodeRenderer);
 
   if(oldGraphComposite->getInputData()->graph==graph) {
-    oldGraphComposite->getInputData()->deleteGlVertexArrayManagerInDestructor(false);
     delete graphComposite->getInputData()->getGlVertexArrayManager();
     graphComposite->getInputData()->setGlVertexArrayManager(oldGraphComposite->getInputData()->getGlVertexArrayManager());
-    // prevent deletion of GlVertexArrayManager
-    // when deleting oldGraphComposite
+    // prevent deletion of GlVertexArrayManager when deleting oldGraphComposite
     oldGraphComposite->getInputData()->setGlVertexArrayManager(NULL);
     graphComposite->getInputData()->getGlVertexArrayManager()->setInputData(graphComposite->getInputData());
   }
