@@ -46,7 +46,7 @@ using namespace tlp;
   Helper storage class to ensure synchronization between panels list and model passed down to opened panels
   */
 Workspace::Workspace(QWidget *parent)
-  : QWidget(parent), _ui(new Ui::Workspace), _currentPanelIndex(0), _model(NULL), _pageCountLabel(NULL) {
+  : QWidget(parent), _ui(new Ui::Workspace), _currentPanelIndex(0), _oldWorkspaceMode(NULL), _focusedPanel(NULL), _focusedPanelHighlighting(false), _model(NULL), _pageCountLabel(NULL) {
   _ui->setupUi(this);
   _ui->startupMainFrame->hide();
   _pageCountLabel = _ui->pagesLabel;
@@ -166,9 +166,9 @@ int Workspace::addPanel(tlp::View* view) {
     updatePanels();
   }
 
-  // Force the first panel's graph combo box update when underleying model has been updated.
+  // Force the first panel's graph combo box update when underlaying model has been updated.
   panel->viewGraphSet(view->graph());
-  emit panelFocused(view);
+  setFocusedPanel(panel);
   return _panels.size()-1;
 }
 
@@ -183,6 +183,10 @@ void Workspace::delView(tlp::View* view) {
 
 void Workspace::panelDestroyed(QObject* obj) {
   WorkspacePanel* panel = static_cast<WorkspacePanel*>(obj);
+
+  if (panel == _focusedPanel)
+    _focusedPanel = NULL;
+
   int removeCount = _panels.removeAll(panel);
 
   if (removeCount==0)
@@ -397,6 +401,12 @@ void Workspace::setActivePanel(tlp::View* view) {
   updatePanels();
 }
 
+void Workspace::setGraphForFocusedPanel(tlp::Graph* g) {
+  if (_focusedPanel && _focusedPanel->isGraphSynchronized() &&
+      _focusedPanel->view()->graph() != g)
+    _focusedPanel->view()->setGraph(g);
+}
+
 WorkspacePanel* Workspace::panelForScene(QObject *obj) {
   WorkspacePanel* p = NULL;
   foreach(WorkspacePanel* panel, _panels) {
@@ -421,7 +431,7 @@ bool Workspace::eventFilter(QObject* obj, QEvent* ev) {
   else if (ev->type() == QEvent::FocusIn) {
     if (dynamic_cast<QGraphicsView*>(obj) != NULL) {
       tlp::WorkspacePanel* panel = static_cast<tlp::WorkspacePanel*>(obj->parent());
-      emit panelFocused(panel->view());
+      setFocusedPanel(panel);
     }
   }
 
@@ -684,5 +694,43 @@ void Workspace::updateStartupMode() {
     _ui->startupImportFrame->setVisible(_model->empty());
     _ui->startupMainFrame->setVisible(!_model->empty());
   }
-
 }
+
+// enable/disable highlight of focused panel
+void Workspace::setFocusedPanelHighlighting(bool h) {
+  _focusedPanelHighlighting = h;
+
+  if (_focusedPanel)
+    _focusedPanel->setHighlightMode(h);
+}
+
+// update focused panel
+void Workspace::setFocusedPanel(WorkspacePanel* panel) {
+  if (_focusedPanel) {
+    if (_focusedPanelHighlighting)
+      _focusedPanel->setHighlightMode(false);
+
+    disconnect(_focusedPanel, SIGNAL(changeGraphSynchronization(bool)),
+               this, SLOT(changeFocusedPanelSynchronization(bool)));
+  }
+
+  _focusedPanel = panel;
+  connect(_focusedPanel, SIGNAL(changeGraphSynchronization(bool)),
+          this, SLOT(changeFocusedPanelSynchronization(bool)));
+
+  if (_focusedPanelHighlighting)
+    _focusedPanel->setHighlightMode(true);
+
+  emit panelFocused(panel->view());
+
+  if (_focusedPanel->isGraphSynchronized())
+    emit focusedPanelSynchronized();
+}
+
+void Workspace::changeFocusedPanelSynchronization(bool s) {
+  if (s)
+    emit focusedPanelSynchronized();
+}
+
+
+
