@@ -88,6 +88,8 @@ WorkspacePanel::WorkspacePanel(tlp::View* view, QWidget *parent)
   _ui->interactorsFrame->installEventFilter(this);
   _ui->dragHandle->setPanel(this);
   _ui->graphCombo->installEventFilter(this);
+  connect(_ui->linkButton, SIGNAL(toggled(bool)),
+          this, SLOT(toggleSynchronization(bool)));
   connect(_ui->closeButton,SIGNAL(clicked()),this,SLOT(close()));
   setView(view);
   setAttribute(Qt::WA_DeleteOnClose);
@@ -487,6 +489,31 @@ void WorkspacePanel::setOverlayMode(bool m) {
   }
 }
 
+void WorkspacePanel::setHighlightMode(bool hm) {
+  // when highlighted the backgroud color
+  // is set to a light green
+  // which made appear a 2 pixel height line
+  // on top of this panel
+  // (only top margin has a non null value in WorkspacePanel.ui)
+  if (hm)
+    _ui->borderFrame->setStyleSheet(QString::fromUtf8("QFrame[border = \"true\"] {\n"
+                                    "border-image:none;\n"
+                                    "background-color: #CBDE5D;\n"
+                                    "color: white;\n"
+                                    "}"));
+  else
+    // restore the style sheet as described in WorkspacePanel.ui
+    _ui->borderFrame->setStyleSheet(QString::fromUtf8("QFrame[border = \"true\"] {\n"
+                                    "border-image:none;\n"
+                                    "background-color: qlineargradient(x1: 0, y1: 0, x2: 0.0, y2: 1.0,\n"
+                                    "stop: 0 #838383,\n"
+                                    "stop: 0.4 #707070,\n"
+                                    "stop: 0.401 #636363,\n"
+                                    "stop: 1 #4a4a4a);\n"
+                                    "color: white;\n"
+                                    "}"));
+}
+
 void WorkspacePanel::dragEnterEvent(QDragEnterEvent * evt) {
   handleDragEnterEvent(evt,evt->mimeData());
 }
@@ -529,3 +556,20 @@ bool WorkspacePanel::handleDropEvent(const QMimeData* mimedata) {
   setOverlayMode(false);
   return graphMime != NULL || panelMime != NULL || algorithmMime != NULL;
 }
+
+bool WorkspacePanel::isGraphSynchronized() const {
+  return _ui->linkButton->isChecked();
+}
+
+void WorkspacePanel::toggleSynchronization(bool f) {
+  if (f) {
+    _ui->linkButton->setIcon(QIcon(":/tulip/gui/icons/16/link.png"));
+    _ui->linkButton->setToolTip("Click here to disable the synchronization with the Graphs panel.\nWhen synchronization is enabled, the current graph of the Graphs panel,\nbecomes the current one in the workspace active panel.");
+  }
+  else {
+    _ui->linkButton->setIcon(QIcon(":/tulip/gui/icons/16/unlink.png"));
+    _ui->linkButton->setToolTip("Click here to enable the synchronization with the Graphs panel.\nWhen synchronization is enabled, the current graph of the Graphs panel,\nbecomes the current one in the workspace active panel.");
+  }
+
+  emit changeGraphSynchronization(f);
+}
