@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLSVGFEEDBACKBUILDER_H
 #define Tulip_GLSVGFEEDBACKBUILDER_H
 
@@ -24,6 +26,7 @@
 #include <sstream>
 
 #include <tulip/GlTLPFeedBackBuilder.h>
+#include <tulip/Color.h>
 
 namespace tlp {
 
@@ -82,3 +85,4 @@ private:
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLFEEDBACKBUILDER_H
+///@endcond
