@@ -25,6 +25,7 @@
 
 #include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlScene.h>
+#include <tulip/GlTools.h>
 #include <tulip/GlXMLTools.h>
 #include <tulip/GlLODSceneVisitor.h>
 #include <tulip/GlCPULODCalculator.h>
@@ -146,7 +147,7 @@ void GlScene::initGlParameters() {
   GLenum error = glGetError();
 
   if ( error != GL_NO_ERROR)
-    tlp::warning() << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "[OpenGL Error] => " << glGetErrorDescription(error).c_str() << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
 
 #endif
 }
@@ -670,32 +671,24 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
   if(h==0)
     h=1;
 
-  GlLODCalculator *selectLODCalculator;
-
-  //check if the layer is in scene
+  //check if the layer is in the scene
   bool layerInScene=true;
 
   if(layer) {
     layerInScene=false;
 
-    for(vector<pair<string,GlLayer *> >::iterator it=layersList.begin(); it!=layersList.end() && layerInScene; ++it) {
+    for(vector<pair<string,GlLayer *> >::const_iterator it=layersList.begin(); it!=layersList.end() && layerInScene; ++it) {
       if(it->second==layer)
         layerInScene=true;
     }
   }
 
-  if(layerInScene) {
-    selectLODCalculator=lodCalculator;
-  }
-  else {
-    selectLODCalculator=lodCalculator->clone();
-  }
+  GlLODCalculator *selectLODCalculator= layerInScene?lodCalculator:lodCalculator->clone();
 
   selectLODCalculator->setRenderingEntitiesFlag((RenderingEntitiesFlag)(RenderingAll | RenderingWithoutRemove));
-
   selectLODCalculator->clear();
 
-  //Collect entities if need
+  //Collect entities if needed
   GlLODSceneVisitor *lodVisitor=new GlLODSceneVisitor(selectLODCalculator,NULL);
 
   if(layerInScene) {
@@ -723,15 +716,14 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
 
   LayersLODVector &layersLODVector=selectLODCalculator->getResult();
 
-  for(vector<LayerLODUnit>::iterator itLayer=layersLODVector.begin(); itLayer!=layersLODVector.end(); ++itLayer) {
-    Camera *camera=(Camera*)((*itLayer).camera);
+  for(vector<LayerLODUnit>::const_iterator itLayer=layersLODVector.begin(); itLayer!=layersLODVector.end(); ++itLayer) {
+    Camera *camera=itLayer->camera;
 
     vector<GlGraphComposite*> compositesToRender;
 
     Vector<int, 4> viewport = camera->getViewport();
 
-    unsigned int size;
-    size=(*itLayer).simpleEntitiesLODVector.size();
+    unsigned int size=itLayer->simpleEntitiesLODVector.size();
 
     if(size==0)
       continue;
@@ -739,7 +731,7 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
     glPushAttrib(GL_ALL_ATTRIB_BITS); //save previous attributes
     glPushClientAttrib(GL_CLIENT_ALL_ATTRIB_BITS); //save previous attributes
 
-    //Allocate memory to store the result oh the selection
+    //Allocate memory to store the result of the selection
     GLuint (*selectBuf)[4] = new GLuint[size][4];
     glSelectBuffer(size*4 , (GLuint *)selectBuf);
     //Activate Open Gl Selection mode
@@ -772,24 +764,20 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
     map<unsigned int, SelectedEntity> idToEntity;
     unsigned int id=1;
 
-    if((type & RenderingSimpleEntities)!=0) {
-      vector<SimpleEntityLODUnit>::iterator it;
-
-      for(it = (*itLayer).simpleEntitiesLODVector.begin(); it!=(*itLayer).simpleEntitiesLODVector.end(); ++it) {
+    if(type & RenderingSimpleEntities) {
+      for(vector<SimpleEntityLODUnit>::const_iterator it = itLayer->simpleEntitiesLODVector.begin(); it!=itLayer->simpleEntitiesLODVector.end(); ++it) {
         if(it->lod<0)
           continue;
 
         idToEntity[id]=SelectedEntity(it->entity);
         glLoadName(id);
         id++;
-        ((it->entity))->draw(20.,camera);
+        it->entity->draw(20.,camera);
       }
     }
 
-    if(((type & RenderingNodes)!=0) || ((type & RenderingEdges)!=0)) {
-      vector<SimpleEntityLODUnit>::iterator it;
-
-      for(it = (*itLayer).simpleEntitiesLODVector.begin(); it!=(*itLayer).simpleEntitiesLODVector.end(); ++it) {
+    if((type & RenderingNodes) || (type & RenderingEdges)) {
+      for(vector<SimpleEntityLODUnit>::const_iterator it = itLayer->simpleEntitiesLODVector.begin(); it!=itLayer->simpleEntitiesLODVector.end(); ++it) {
         if(it->lod<0)
           continue;
 
@@ -811,7 +799,7 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
 
     delete[] selectBuf;
 
-    for(vector<GlGraphComposite*>::iterator it=compositesToRender.begin(); it!=compositesToRender.end(); ++it) {
+    for(vector<GlGraphComposite*>::const_iterator it=compositesToRender.begin(); it!=compositesToRender.end(); ++it) {
       (*it)->selectEntities(camera,type,x,y,w,h,selectedEntities);
     }
 
