@@ -23,6 +23,7 @@
 #define MAX_THREADS 1
 #endif
 
+#include <tulip/TulipException.h>
 #include <tulip/GraphTools.h>
 #include <tulip/DrawingTools.h>
 #include <tulip/StableIterator.h>
@@ -162,12 +163,13 @@ DoubleProperty * EdgeBundling::computeWeights(Graph *graph) {
   edge e;
   forEach(e, graph->getEdges()) {
     const pair<node, node>& ends = graph->ends(e);
-    Coord a = layout->getNodeValue(ends.first);
-    Coord b = layout->getNodeValue(ends.second);
-    double initialWeight = pow((double) (a-b).norm(), longEdges);
+    const Coord& a = layout->getNodeValue(ends.first);
+    const Coord& b = layout->getNodeValue(ends.second);
+    double abNorm = (double) (a-b).norm();
+    double initialWeight = pow(abNorm, longEdges);
 
     if (ntype->getEdgeValue(e) == 2 && !edgeNodeOverlap)
-      initialWeight = (a-b).norm();
+      initialWeight = abNorm;
 
     weights->setEdgeValue(e, initialWeight );
   }
@@ -217,7 +219,9 @@ void EdgeBundling::fixEdgeType() {
     }
 
     const pair<node, node>& ends = graph->ends(e);
+
     bool inSrc = oriGraph->isElement(ends.first);
+
     bool inTgt = oriGraph->isElement(ends.second);
 
     if(!inSrc && !inTgt)
@@ -323,24 +327,31 @@ bool EdgeBundling::run() {
   std::vector<tlp::edge> removedEdges;
   tlp::SimpleTest::makeSimple(oriGraph, removedEdges);
 
-  // Grid graph computation first step : generate quad-tree/octree
-  if (layout3D) {
-    OctreeBundle::compute(graph, splitRatio, layout, size);
-    edge e;
-    stableForEach(e, graph->getEdges()) {
-      if(oriGraph->isElement(e)) continue;
+  try {
+    // Grid graph computation first step : generate quad-tree/octree
+    if (layout3D) {
+      OctreeBundle::compute(graph, splitRatio, layout, size);
+      edge e;
+      stableForEach(e, graph->getEdges()) {
+        if(oriGraph->isElement(e)) continue;
 
-      graph->delEdge(e);
+        graph->delEdge(e);
+      }
+
+      if (sphereLayout) {
+        centerOnOriginAndScale(graph, layout, dist*2.);
+        addSphereGraph(graph, dist+0.5*dist);
+        addSphereGraph(graph, dist-0.2*dist);
+      }
     }
-
-    if (sphereLayout) {
-      centerOnOriginAndScale(graph, layout, dist*2.);
-      addSphereGraph(graph, dist+0.5*dist);
-      addSphereGraph(graph, dist-0.2*dist);
+    else {
+      QuadTreeBundle::compute(graph, splitRatio, layout, size);
     }
   }
-  else {
-    QuadTreeBundle::compute(graph, splitRatio, layout, size);
+  catch(tlp::TulipException& e) {
+    string errorMsg(e.what());
+    pluginProgress->setError(errorMsg);
+    return false;
   }
 
   // Grid graph computation second step : generate a voronoi diagram
@@ -361,7 +372,7 @@ bool EdgeBundling::run() {
     stableForEach(n, graph->getNodes()) {
       if(oriGraph->isElement(n)) continue;
 
-      Coord c = layout->getNodeValue(n);
+      const Coord& c = layout->getNodeValue(n);
 
       if(c.norm() < 0.9 * dist) {
         graph->delNode(n, true);
@@ -381,10 +392,11 @@ bool EdgeBundling::run() {
       pair<node, node> ends = graph->ends(e);
       const Coord &a = layout->getNodeValue(ends.first);
       const Coord &b = layout->getNodeValue(ends.second);
-      double initialWeight = pow((double) (a-b).norm(), longEdges);
+      double abNorm = (double) (a-b).norm();
+      double initialWeight = pow(abNorm, longEdges);
 
       if (ntype->getEdgeValue(e) == 2 && !edgeNodeOverlap)
-        initialWeight = (a-b).norm();
+        initialWeight = abNorm;
 
       mWeights.set(e.id, initialWeight);
       mWeightsInit.set(e.id, initialWeight);
