@@ -16,31 +16,27 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
 
-/**
- * TODO Add documentation
- **/
-
 namespace {
 
 const char * paramHelp[] = {
   // nodes
   HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "int" ) \
+  HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "5" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of nodes composing the completed graph." \
+  "Number of nodes in the final graph." \
   HTML_HELP_CLOSE(),
   // bool
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "true" ) \
   HTML_HELP_BODY() \
-  "This parameter defines wether or not the graph is undirected, if false two edges will be created between each couple of nodes." \
+  "If true, the generated graph is undirected. If false, two edges are created between each pair of nodes." \
   HTML_HELP_CLOSE(),
 
 };
@@ -49,25 +45,24 @@ const char * paramHelp[] = {
 
 class CompleteGraph:public ImportModule {
 public:
-  CompleteGraph(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("nodes",paramHelp[0],"5");
-    addParameter<bool>("undirected",paramHelp[1],"true");
-  }
-  ~CompleteGraph() {
+  PLUGININFORMATION("Complete General Graph","Auber","16/12/2002","Imports a new complete graph.","1.1","Graph")
+  CompleteGraph(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("nodes",paramHelp[0],"5");
+    addInParameter<bool>("undirected",paramHelp[1],"true");
   }
 
-  bool import(const string &) {
+  bool importGraph() {
     unsigned int nbNodes  = 5;
-    bool undirected = false;
+    bool undirected = true;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("nodes", nbNodes);
       dataSet->get("undirected", undirected);
     }
 
     if (nbNodes == 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: number of nodes cannot be null"));
+        pluginProgress->setError("Error: number of nodes must be greater than 0");
 
       return false;
     }
@@ -77,9 +72,16 @@ public:
 
     vector<node> nodes(nbNodes);
 
+    graph->reserveNodes(nbNodes);
+
     for (size_t j=0; j<nbNodes; ++j)
       nodes[j] = graph->addNode();
 
+    if(undirected)
+      graph->reserveEdges(nbNodes-1);
+    else
+      graph->reserveEdges(2*(nbNodes-1));
+
     for (size_t i=0; i < nbNodes-1; ++i)
       for (size_t j = i+1; j < nbNodes; ++j) {
         graph->addEdge(nodes[i], nodes[j]);
@@ -92,4 +94,4 @@ public:
   }
 };
 
-IMPORTPLUGINOFGROUP(CompleteGraph,"Complete General Graph","Auber","16/12/2002","","1.1","Graphs")
+PLUGIN(CompleteGraph)
