@@ -19,22 +19,6 @@
 #include <ogdf/upward/VisibilityLayout.h>
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
 
-namespace {
-
-const char * paramHelp[] = {
-  HTML_HELP_OPEN()
-  HTML_HELP_DEF( "type", "int" )
-  HTML_HELP_BODY()
-  "the minimum grid distance."
-  HTML_HELP_CLOSE(),
-  HTML_HELP_OPEN()
-  HTML_HELP_DEF( "type", "bool" )
-  HTML_HELP_BODY()
-  "Sets the option for transposing layout vertically ."
-  HTML_HELP_CLOSE()
-};
-}
-
 // comments below have been extracted from OGDF/src/upward/VisibilityLayout.cpp
 /** \addtogroup layout */
 
@@ -85,8 +69,20 @@ class OGDFVisibility : public OGDFLayoutPluginBase {
 public:
   PLUGININFORMATION("Visibility (OGDF)","Hoi-Ming Wong","12/11/2007","Ok","1.0","Hierarchical")
   OGDFVisibility(const tlp::PluginContext* context) :OGDFLayoutPluginBase(context, new ogdf::VisibilityLayout()) {
-    addInParameter<int>("minimum grid distance", paramHelp[0], "1");
-    addInParameter<bool>("transpose", paramHelp[1], "false");
+    addInParameter<int>("minimum grid distance",
+                        HTML_HELP_OPEN()
+                        HTML_HELP_DEF( "type", "int" )
+                        HTML_HELP_BODY()
+                        "The minimum grid distance."
+                        HTML_HELP_CLOSE(),
+                        "1");
+    addInParameter<bool>("transpose",
+                         HTML_HELP_OPEN()
+                         HTML_HELP_DEF( "type", "bool" )
+                         HTML_HELP_BODY()
+                         "The parameter for transposing the layout vertically ."
+                         HTML_HELP_CLOSE(),
+                         "false");
   }
 
   ~OGDFVisibility() {}
