@@ -143,7 +143,6 @@ void GraphPerspective::log(QtMsgType type, const QMessageLogContext &context, co
 #else
 
 void graphPerspectiveLogger(QtMsgType type, const char* msg) {
-  std::cerr << msg << std::endl;
   static_cast<GraphPerspective*>(Perspective::instance())->log(type,msg);
 }
 
@@ -197,9 +196,8 @@ bool GraphPerspective::eventFilter(QObject* obj, QEvent* ev) {
     if(_graphs->needsSaving()) {
       QMessageBox::StandardButton answer = QMessageBox::question(_mainWindow, trUtf8("Save"), trUtf8("The project has been modified, do you want to save your changes ?"),QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel | QMessageBox::Escape);
 
-      if(answer == QMessageBox::Yes)
-        save();
-      else if(answer == QMessageBox::Cancel) {
+      if ((answer == QMessageBox::Yes && !save()) ||
+          (answer == QMessageBox::Cancel)) {
         ev->ignore();
         return true;
       }
@@ -232,6 +230,7 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   _ui->singleModeButton->setEnabled(false);
   _ui->singleModeButton->hide();
   _ui->workspace->setSingleModeSwitch(_ui->singleModeButton);
+  _ui->workspace->setFocusedPanelHighlighting(true);
   _ui->splitModeButton->setEnabled(false);
   _ui->splitModeButton->hide();
   _ui->workspace->setSplitModeSwitch(_ui->splitModeButton);
@@ -273,8 +272,10 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
 #endif
 
   connect(_ui->workspace,SIGNAL(addPanelRequest(tlp::Graph*)),this,SLOT(createPanel(tlp::Graph*)));
+  connect(_ui->workspace,SIGNAL(focusedPanelSynchronized()),this,SLOT(focusedPanelSynchronized()));
   connect(_graphs,SIGNAL(currentGraphChanged(tlp::Graph*)),this,SLOT(currentGraphChanged(tlp::Graph*)));
   connect(_graphs,SIGNAL(currentGraphChanged(tlp::Graph*)),_ui->algorithmRunner,SLOT(setGraph(tlp::Graph*)));
+  connect(_ui->graphHierarchiesEditor,SIGNAL(changeSynchronization(bool)),this,SLOT(changeSynchronization(bool)));
 
   // Connect actions
   connect(_ui->actionMessages_log,SIGNAL(triggered()),this,SLOT(showLogger()));
@@ -355,7 +356,8 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
     connect(h,SIGNAL(expanded(bool)),this,SLOT(refreshDockExpandControls()));
   }
 
-#if defined(__linux) // Hide plugins center features on linux
+#if !defined(__APPLE__) && !defined(_WIN32)
+  // Hide plugins center when not on MacOS or Windows
   _ui->pluginsButton->hide();
   _ui->menuHelp->removeAction(_ui->actionPlugins_Center);
 #endif
@@ -570,15 +572,24 @@ void GraphPerspective::panelFocused(tlp::View* view) {
   connect(view,SIGNAL(graphSet(tlp::Graph*)),this,SLOT(focusedPanelGraphSet(tlp::Graph*)));
   focusedPanelGraphSet(view->graph());
 }
+
+void GraphPerspective::changeSynchronization(bool s) {
+  _ui->workspace->setFocusedPanelHighlighting(s);
+}
+
 void GraphPerspective::focusedPanelGraphSet(Graph* g) {
   _graphs->setCurrentGraph(g);
 }
 
-void GraphPerspective::save() {
-  saveAs(_project->projectFile());
+void GraphPerspective::focusedPanelSynchronized() {
+  _ui->workspace->setGraphForFocusedPanel(_graphs->currentGraph());
 }
 
-void GraphPerspective::saveAs(const QString& path) {
+bool GraphPerspective::save() {
+  return saveAs(_project->projectFile());
+}
+
+bool GraphPerspective::saveAs(const QString& path) {
   if (path.isEmpty()) {
     QString path = QFileDialog::getSaveFileName(_mainWindow,trUtf8("Save project"),QString(),"Tulip Project (*.tlpx)");
 
@@ -586,10 +597,10 @@ void GraphPerspective::saveAs(const QString& path) {
       if (!path.endsWith(".tlpx"))
         path+=".tlpx";
 
-      saveAs(path);
+      return saveAs(path);
     }
 
-    return;
+    return false;
   }
 
   SimplePluginProgressDialog progress(_mainWindow);
@@ -599,6 +610,8 @@ void GraphPerspective::saveAs(const QString& path) {
   _ui->workspace->writeProject(_project,rootIds,&progress);
   _project->write(path,&progress);
   TulipSettings::instance().addToRecentDocuments(path);
+
+  return true;
 }
 
 void GraphPerspective::open(QString fileName) {
@@ -962,6 +975,9 @@ void GraphPerspective::currentGraphChanged(Graph *graph) {
     _ui->pythonButton->setChecked(false);
     setSearchOutput(false);
   }
+  else {
+    _ui->workspace->setGraphForFocusedPanel(graph);
+  }
 }
 
 void GraphPerspective::CSVImport() {
@@ -1153,8 +1169,8 @@ void GraphPerspective::openRecentFile() {
   open(action->text());
 }
 
-void GraphPerspective::treatEvent(const tlp::Event &message) {
-  if (dynamic_cast<const tlp::PluginEvent*>(&message)) {
+void GraphPerspective::treatEvent(const tlp::Event &ev) {
+  if (dynamic_cast<const tlp::PluginEvent*>(&ev)) {
     pluginsListChanged();
   }
 }
