@@ -182,8 +182,11 @@ void SuperGraphTest::testDegree() {
   build(100, 100);
   degreeCheck(graph);
   Graph *gr = graph->addCloneSubGraph();
-  Graph *gr1 = graph->addCloneSubGraph();
+  CPPUNIT_ASSERT_EQUAL(graph, gr->getSuperGraph());
+  Graph *gr1 = gr->addCloneSubGraph("gr1", true);
+  CPPUNIT_ASSERT_EQUAL(graph, gr1->getSuperGraph());
   Graph *gr2 = gr1->addCloneSubGraph();
+  CPPUNIT_ASSERT_EQUAL(gr1, gr2->getSuperGraph());
 
   degreeCheck(graph);
   degreeCheck(gr);
@@ -212,6 +215,10 @@ void SuperGraphTest::testDegree() {
   degreeCheck(gr1);
   degreeCheck(gr2);
 
+  gr1->delSubGraph(gr2);
+  graph->delSubGraph(gr1);
+  graph->delSubGraph(gr);
+
   graph->clear();
   gr1 = graph->addCloneSubGraph();
   gr2 = gr1->addCloneSubGraph();
@@ -300,9 +307,7 @@ void SuperGraphTest::testAddDel() {
 
   CPPUNIT_ASSERT_EQUAL(NB_ADD, graph->numberOfNodes());
 
-  StlIterator<node, std::vector<node>::const_iterator> itn(nodes.begin(),
-      nodes.end());
-  graph->delNodes(&itn);
+  graph->delNodes(nodes);
 
   CPPUNIT_ASSERT_EQUAL(0u, graph->numberOfNodes());
 
